An auxiliary Dart library.
It provides an assortment of useful general-purpose classes, functions, constants, etc. Most of these are standalone utilities; some are organized and interconnected.
Overview
Collections
-
The
EquatableList,EquatableMap, andEquatableSetclasses are unmodifiable collections with deep equality. -
The
LateListclass is an unmodifiableDelegatingListthat uses anIterableas its source but iterates over it only once and only upon the first access to any element. -
The
SortedMapclass is aTreeSet-basedMap. The ordering of keys is defined by a givencomparatoror by the defaultComparable.compareTofunction. -
The
IMultimapclass is anIMap-based immutable associative container that maps a key to multiple values. -
The
Array2Dclass is a two-dimensional array of objects.
Error handling
-
The
gated,gatedAsync,later, andalonefunctions, along with theglobalGateClosedproperty, help to prevent critical code sections (for example, data outputting code) from running in the case of a fatal program failure. -
The
RuntimeErrorandRuntimeExceptionclasses may be used as bases for custom errors and exceptions. Both classes are derived from theRuntimeThrowablemixin. -
The
WrappingErrorandWrappingExceptionclasses may be used when a thrownObjectand its correspondingStackTracemust be handled as a single entity.
Miscellaneous
-
The
logproperty provides convenient access to the logging functionality for libraries and applications. -
The
ActorBasemixin is a model for a possible lifecycle of anObjectinstance. TheActorandActorAsyncmixins supplementActorBasewith initialization and deactivation routines for synchronous and asynchronous scenarios. -
The
StateMachineclass is aStream-based Finite State Machine implementation. -
See the package documentation for the full API.
Libraries
- auxiliary
- An auxiliary Dart library.